package types

import (
	"bytes"
	"encoding/binary"
)

type TelegramHeader struct {
	MessageLength   int16
	TelegramID      int16
	SequenceCounter int16
	Flags           int16
	TimeStamp       [8]int16
}

type PrintData struct {
	Header                *TelegramHeader
	DateTime              [23]byte
	L2PackageId           int32
	L3PackageId           [6]byte
	ProductionOrderNo     int32
	CustomerOrderNo       int32
	CustomerName          [30]byte
	LogoCode              [3]byte
	SteelGrade            [15]byte
	MaterialCode          [18]byte
	HeatId                [10]byte
	SectionType           [20]byte
	PackageDimensions     [3]float32
	PackageWeight         float32
	SectionDimensions     [3]float32
	NumberSections        int32
	NumberLayers          int32
	NumberSectionsInLayer int32
	FreeTxtLp             [180]byte
}

func (p *PrintData) FromBytes(byteData []byte) error {
	// create reader
	reader := bytes.NewReader(byteData)
	// convert reader binary data
	if err := binary.Read(reader, binary.LittleEndian, p); err != nil {
		return err
	}
	return nil
}
